@@ -4,39 +4,19 @@ import copy
 import six
 import inspect
 import importlib
-# import warnings
+import contextlib
 import weakref
 from collections import OrderedDict
 from yggdrasil.doctools import docs2args
 
 
 _registry = {}
-_registry_defaults = {}
-_registry_base_classes = {}
-_registry_class2subtype = {}
 _registry_complete = False
-_comptype2key = {'comm': 'commtype',
-                 'file': 'filetype',
-                 'model': 'language',
-                 'connection': 'connection_type',
-                 # 'datatype': None,
-                 'serializer': 'seritype',
-                 'filter': 'filtertype',
-                 'transform': 'transformtype'}
-# 'compiler': 'toolname',
-# 'linker': 'toolname',
-# 'archiver': 'toolname'}
-_comptype2mod = {'serializer': 'serialize',
-                 'comm': 'communication',
-                 'file': 'communication',
-                 'model': 'drivers',
-                 'connection': 'drivers',
-                 'filter': 'communication.filters',
-                 'transform': 'communication.transforms'}
-# 'datatype': ['metaschema', 'datatypes'],
-# 'compiler': 'drivers',
-# 'linker': 'drivers',
-# 'archiver': 'drivers'}
+
+
+class ComponentError(BaseException):
+    r"""Error raised when there is a problem import a component."""
+    pass
 
 
 class ClassRegistry(OrderedDict):
@@ -46,7 +26,6 @@ class ClassRegistry(OrderedDict):
         module = inspect.getmodule(inspect.stack()[1][0])
         self._module = module.__name__
         self._directory = os.path.dirname(module.__file__)
-        # self._schema_directory = os.path.join(self._directory, 'schemas')
         self._import_function = import_function
         self._imported = False
         super(ClassRegistry, self).__init__(*args, **kwargs)
@@ -56,7 +35,7 @@ class ClassRegistry(OrderedDict):
         if self._imported:
             return
         self._imported = True
-        for x in glob.glob(os.path.join(self._directory, '*.py')):
+        for x in sorted(glob.glob(os.path.join(self._directory, '*.py'))):
             mod = os.path.basename(x)[:-3]
             if not mod.startswith('__'):
                 importlib.import_module(self._module + '.%s' % mod)
@@ -98,52 +77,72 @@ class ClassRegistry(OrderedDict):
         return super(ClassRegistry, self).__contains__(key)
 
 
-def init_registry():
+def registration_in_progress():
+    r"""Determine if a registration is in progress."""
+    return bool(os.environ.get('YGGDRASIL_REGISTRATION_IN_PROGRESS', None))
+
+
+@contextlib.contextmanager
+def registering(recurse=False):
+    r"""Context for preforming registration."""
+    if not recurse:
+        assert(not registration_in_progress())
+    try:
+        previous = os.environ.get('YGGDRASIL_REGISTRATION_IN_PROGRESS', None)
+        os.environ['YGGDRASIL_REGISTRATION_IN_PROGRESS'] = '1'
+        yield
+    finally:
+        if previous is None:
+            if 'YGGDRASIL_REGISTRATION_IN_PROGRESS' in os.environ:
+                del os.environ['YGGDRASIL_REGISTRATION_IN_PROGRESS']
+        else:
+            os.environ['YGGDRASIL_REGISTRATION_IN_PROGRESS'] = previous
+
+
+def init_registry(recurse=False):
     r"""Initialize the registries and schema."""
+    from yggdrasil.tools import import_all_modules
     global _registry
     global _registry_complete
-    if not _registry_complete:
-        comp_list = []
-        mod_list = []
-        for k, v in _comptype2mod.items():
-            if v not in mod_list:
-                comp_list.append(k)
-                mod_list.append(v)
-        for k in comp_list:
-            import_all_components(k)
+    with registering(recurse=recurse):
+        import_all_modules(exclude=['yggdrasil.examples',
+                                    'yggdrasil.languages',
+                                    'yggdrasil.interface',
+                                    'yggdrasil.timing'],
+                           do_first=['yggdrasil.serialize'])
         _registry_complete = True
     return _registry
 
 
-# This dosn't work as desried because classes that have already been imported
-# will not call registration on second import
-# def clear_registry():
-#     r"""Reset registries."""
-#     global _registry
-#     global _registry_defaults
-#     global _registry_class2subtype
-#     global _registry_complete
-#     _registry = {}
-#     _registry_defaults = {}
-#     _registry_class2subtype = {}
-#     _registry_complete = False
+def get_registry(comptype=None):
+    r"""Get the registry that should be used for looking up components.
+
+    Args:
+        comptype (str, optional): The name of a component to get the
+            registry for. Defaults to None and the entire registry will be
+            returned.
+
+    """
+    global _registry
+    if registration_in_progress():
+        out = _registry
+    else:
+        from yggdrasil import constants
+        out = constants.COMPONENT_REGISTRY
+    if comptype:
+        if comptype not in out:  # pragma: debug
+            raise Exception(f"Importing a component type that has not yet "
+                            f"been registered: {comptype}")
+        out = out[comptype]
+    return out
+
 
-    
 def suspend_registry():
     r"""Suspend the registry by storing the global registries in a dictionary."""
     global _registry
-    global _registry_defaults
-    global _registry_base_classes
-    global _registry_class2subtype
     global _registry_complete
-    out = {'_registry': _registry, '_registry_defaults': _registry_defaults,
-           '_registry_base_classes': _registry_base_classes,
-           '_registry_class2subtype': _registry_class2subtype,
-           '_registry_complete': _registry_complete}
+    out = {'_registry': _registry, '_registry_complete': _registry_complete}
     _registry = {}
-    _registry_defaults = {}
-    _registry_base_classes = {}
-    _registry_class2subtype = {}
     _registry_complete = False
     return out
 
@@ -151,59 +150,21 @@ def suspend_registry():
 def restore_registry(reg_dict):
     r"""Restore the registry to values in the provided dictionary."""
     global _registry
-    global _registry_defaults
-    global _registry_base_classes
-    global _registry_class2subtype
     global _registry_complete
     _registry = reg_dict['_registry']
-    _registry_defaults = reg_dict['_registry_defaults']
-    _registry_base_classes = reg_dict['_registry_base_classes']
-    _registry_class2subtype = reg_dict['_registry_class2subtype']
     _registry_complete = reg_dict['_registry_complete']
 
 
-def import_all_components(comptype):
-    r"""Dynamically import all component classes for a component type.
-
-    Args:
-        comptype (str): Component type.
-
-    """
-    # Get module and directory
-    mod = copy.deepcopy(_comptype2mod[comptype])
-    moddir = os.path.join(*copy.deepcopy(_comptype2mod[comptype]).split('.'))
-    # The next three lines will be required if there are ever any components
-    # nested in multiple directories (e.g. metaschema/datatypes)
-    # if isinstance(mod, list):
-    #     mod = '.'.join(mod)
-    #     moddir = os.path.join(*moddir)
-    moddir = os.path.join(os.path.dirname(__file__), moddir)
-    modbase = importlib.import_module('yggdrasil.%s' % mod)
-    non_comp = [os.path.splitext(x)[0] for x in
-                getattr(modbase, '_non_component_modules', [])]
-    # Import all files
-    for x in glob.glob(os.path.join(moddir, '*.py')):
-        xbase = os.path.splitext(os.path.basename(x))[0]
-        if (not xbase.startswith('__')) and (xbase not in non_comp):
-            importlib.import_module('yggdrasil.%s.%s'
-                                    % (mod, xbase))
-
-
-def import_component(comptype, subtype=None, without_schema=False,
-                     **kwargs):
+def import_component(comptype, subtype=None, **kwargs):
     r"""Dynamically import a component by name.
 
     Args:
         comptype (str): Component type.
-        subtype (str, optional): Component subtype. If subtype is not one of the
-            registered subtypes for the specified comptype, subtype is treated
-            as the name of class. Defaults to None if not provided and the
-            default subtype defined in the schema for the specified component
-            will be used.
-        without_schema (bool, optional): If True, the schema is not used to
-            import the component and subtype must be the name of a component
-            class. Defaults to False. subtype must be provided if without_schema
-            is True.
+        subtype (str, optional): Component subtype. If subtype is not one of
+            the registered subtypes for the specified comptype, subtype is
+            treated as the name of class. Defaults to None if not provided and
+            the default subtype defined in the schema for the specified
+            component will be used.
         **kwargs: Additional keyword arguments are used to determine the
             subtype if it is None.
 
@@ -211,70 +172,39 @@ def import_component(comptype, subtype=None, without_schema=False,
         class: Component class.
 
     Raises:
-        ValueError: If subtype is not provided, but without_schema is True.
-        ValueError: If comptype is not a registered component type.
-        ValueError: If subtype is not a registered subtype or the name of a
-            registered subtype class for the specified comptype.
+        ComponentError: If comptype is not a registered component type.
+        ComponentError: If subtype is not a registered subtype or the name of
+            a registered subtype class for the specified comptype.
             
 
     """
-    # Get module
-    mod = _comptype2mod[comptype]
-    # if isinstance(mod, list):
-    #     mod = '.'.join(mod)
-    # Set direct import shortcuts for unregistered classes
-    if (((subtype is None) and (comptype in _comptype2key)
-         and (_comptype2key[comptype] in kwargs))):
-        subtype = kwargs[_comptype2key[comptype]]
+    registry = get_registry(comptype=comptype)
+    if subtype is None:
+        subtype = kwargs.get(registry["key"], None)
     if (comptype == 'comm') and (subtype is None):
         subtype = 'DefaultComm'
-    if (((comptype in ['comm', 'file']) and (subtype is not None)
-         and ((subtype == 'CommBase') or subtype.endswith('Comm')))):
-        without_schema = True
-    # Set default based on registry to avoid schema if possible
-    if (subtype is None) and (comptype in _registry_defaults):
-        subtype = _registry_defaults.get(comptype, None)
-    # Check registered components to prevent importing multiple times
-    if subtype in _registry.get(comptype, {}):
-        out_cls = _registry[comptype][subtype]
-    elif subtype in _registry_class2subtype.get(comptype, {}):
-        out_cls = _registry[comptype][_registry_class2subtype[comptype][subtype]]
+    if subtype is None:
+        subtype = registry["default"]
+    if subtype in registry["subtypes"]:
+        class_name = registry["subtypes"][subtype]
     else:
-        # Get class name
-        if without_schema:
-            if subtype is None:  # pragma: debug
-                raise ValueError("subtype must be provided if without_schema is True.")
-            class_name = subtype
-        else:
-            from yggdrasil.schema import get_schema
-            s = get_schema().get(comptype, None)
-            if s is None:  # pragma: debug
-                raise ValueError("Unrecognized component type: %s" % comptype)
-            if subtype is None:  # pragma: no cover
-                # This will only be called if the test is run before the component
-                # module is imported
-                subtype = s.default_subtype
-            if subtype in s.class2subtype:
-                class_name = subtype
-            else:
-                class_name = s.subtype2class.get(subtype, None)
-                if class_name is None:
-                    # Attempt file since they are subclass of comm
-                    if (comptype == 'comm'):
-                        try:
-                            return import_component('file', subtype)
-                        except ValueError:
-                            pass
-                    raise ValueError("Unrecognized %s subtype: %s"
-                                     % (comptype, subtype))
+        class_name = subtype
+    # Check registered components to prevent importing multiple times
+    if class_name not in registry.get("classes", {}):
+        registry.setdefault("classes", {})
         try:
-            out_mod = importlib.import_module('yggdrasil.%s.%s' % (mod, class_name))
-        except ImportError:  # pragma: debug
-            import_all_components(comptype)
-            return import_component(comptype, subtype=subtype,
-                                    without_schema=without_schema,
-                                    **kwargs)
-        out_cls = getattr(out_mod, class_name)
+            registry["classes"][class_name] = getattr(
+                importlib.import_module(f"{registry['module']}.{class_name}"),
+                class_name)
+        except ImportError:
+            if comptype == 'comm':
+                try:
+                    return import_component('file', subtype, **kwargs)
+                except ComponentError:
+                    pass
+            raise ComponentError(f"Could not locate a {comptype} component "
+                                 f"{subtype}.")
+    out_cls = registry["classes"][class_name]
     # Check for an aliased class
     if hasattr(out_cls, '_get_alias'):
         out_cls = out_cls._get_alias()
@@ -303,13 +233,13 @@ def create_component(comptype, subtype=None, **kwargs):
             options.
     
     Raises:
-        ValueError: If comptype is not a registered component type.
+        ComponentError: If comptype is not a registered component type.
 
     """
     from yggdrasil.schema import get_schema
     s = get_schema().get(comptype, None)
     if s is None:  # pragma: debug
-        raise ValueError("Unrecognized component type: %s" % comptype)
+        raise ComponentError("Unrecognized component type: %s" % comptype)
     if s.subtype_key in kwargs:
         subtype = kwargs[s.subtype_key]
     if subtype is None:
@@ -318,18 +248,13 @@ def create_component(comptype, subtype=None, **kwargs):
     return cls(**kwargs)
 
 
-def get_component_base_class(comptype, subtype=None, without_schema=False,
-                             **kwargs):
+def get_component_base_class(comptype, subtype=None, **kwargs):
     r"""Determine the base class for a component type.
 
     Args:
         comptype (str): The name of a component to test against.
         subtype (str, optional): Subtype to use to determine the component
             base class. Defaults to None.
-        without_schema (bool, optional): If True, the schema is not used to
-            import the component and subtype must be the name of a component
-            class. Defaults to False. subtype must be provided if without_schema
-            is True.
         **kwargs: Additional keyword arguments are used to determine the
             subtype if it is None.
     
@@ -337,33 +262,20 @@ def get_component_base_class(comptype, subtype=None, without_schema=False,
         ComponentBase: Component base class.
 
     """
-    if comptype in _registry_base_classes:
-        base_class_name = _registry_base_classes[comptype]
-    else:  # pragma: no cover
-        # Only called during initial import which is not covered by
-        # the test runner
-        default_class = import_component(comptype, subtype=subtype,
-                                         without_schema=without_schema,
-                                         **kwargs)
-        base_class_name = default_class._schema_base_class
-    base_class = import_component(comptype, subtype=base_class_name,
-                                  without_schema=True)
-    return base_class
+    registry = get_registry(comptype=comptype)
+    base_class_name = registry['base']
+    return import_component(comptype, subtype=base_class_name, **kwargs)
 
 
-def isinstance_component(x, comptype, subtype=None, without_schema=False,
-                         **kwargs):
+def isinstance_component(x, comptype, subtype=None, **kwargs):
     r"""Determine if an object is an instance of a component type.
 
     Args:
         x (object): Object to test.
-        comptype (str, list): The name of one or more components to test against.
+        comptype (str, list): The name of one or more components to test
+            against.
         subtype (str, optional): Subtype to use to determine the component
             base class. Defaults to None.
-        without_schema (bool, optional): If True, the schema is not used to
-            import the component and subtype must be the name of a component
-            class. Defaults to False. subtype must be provided if without_schema
-            is True.
         **kwargs: Additional keyword arguments are used to determine the
             subtype if it is None.
 
@@ -378,7 +290,6 @@ def isinstance_component(x, comptype, subtype=None, without_schema=False,
         else:
             return False
     base_class = get_component_base_class(comptype, subtype=subtype,
-                                          without_schema=without_schema,
                                           **kwargs)
     return isinstance(x, base_class)
 
@@ -474,12 +385,13 @@ class ComponentMeta(type):
                 args_dict = docs2args(x.__doc__)
                 for k, v in cls._schema_properties.items():
                     if k in args_dict:
-                        v.setdefault('description', args_dict[k]['description'])
+                        v.setdefault('description',
+                                     args_dict[k]['description'])
             # Determine base class
-            global _registry_base_classes
             if cls._schema_base_class is None:
-                if cls._schema_type in _registry_base_classes:
-                    cls._schema_base_class = _registry_base_classes[cls._schema_type]
+                reg = get_registry()
+                if cls._schema_type in reg:
+                    cls._schema_base_class = reg[cls._schema_type]['base']
                 else:
                     base_comp = cls.__name__
                     for i, x in enumerate(cls.__mro__):
@@ -487,29 +399,30 @@ class ComponentMeta(type):
                             break
                         base_comp = x.__name__
                     else:  # pragma: debug
-                        raise RuntimeError(("Could not determine base class for %s "
-                                            "from %s.") % (cls, bases))
+                        raise RuntimeError(
+                            f"Could not determine base class for {cls} "
+                            f"from {bases}.")
                     cls._schema_base_class = base_comp
             # Register
             global _registry
-            global _registry_defaults
-            global _registry_class2subtype
             yaml_typ = cls._schema_type
             default_subtype = cls._schema_properties.get(
                 cls._schema_subtype_key, {}).get('default',
                                                  cls._schema_subtype_default)
             if yaml_typ not in _registry:
-                _registry[yaml_typ] = OrderedDict()
-                _registry_defaults[yaml_typ] = default_subtype
-                _registry_base_classes[yaml_typ] = cls._schema_base_class
-                _registry_class2subtype[yaml_typ] = {}
+                _registry[yaml_typ] = OrderedDict([
+                    ("classes", OrderedDict()),
+                    ("module", '.'.join(cls.__module__.split('.')[:-1])),
+                    ("default", default_subtype),
+                    ("base", cls._schema_base_class),
+                    ("key", cls._schema_subtype_key),
+                    ("subtypes", {})])
             elif default_subtype is not None:
-                assert(_registry_defaults[yaml_typ] == default_subtype)
-            if cls.__name__ not in _registry[yaml_typ]:
-                _registry[yaml_typ][cls.__name__] = cls
-                _registry_class2subtype[yaml_typ][subtype] = cls.__name__
-            if not (os.environ.get('YGG_RUNNING_YGGSCHEMA', 'None').lower()
-                    in ['true', '1']):
+                assert(_registry[yaml_typ]["default"] == default_subtype)
+            if cls.__name__ not in _registry[yaml_typ]["classes"]:
+                _registry[yaml_typ]["classes"][cls.__name__] = cls
+                _registry[yaml_typ]["subtypes"][subtype] = cls.__name__
+            if not registration_in_progress():
                 cls.after_registration(cls)
                 cls.finalize_registration(cls)
         return cls
@@ -693,19 +606,19 @@ class ComponentBase(ComponentBaseUnregistered):
     def before_registration(cls):
         r"""Operations that should be performed to modify class attributes prior
         to registration. These actions will still be performed if the environment
-        variable YGG_RUNNING_YGGSCHEMA is set."""
+        variable YGGDRASIL_REGISTRATION_IN_PROGRESS is set."""
         pass
 
     @staticmethod
     def after_registration(cls):
         r"""Operations that should be preformed to modify class attributes after
         registration. These actions will not be performed if the environment
-        variable YGG_RUNNING_YGGSCHEMA is set."""
+        variable YGGDRASIL_REGISTRATION_IN_PROGRESS is set."""
         pass
 
     @staticmethod
     def finalize_registration(cls):
         r"""Final operations to perform after a class has been fully initialized.
         These actions will not be performed if the environment variable
-        YGG_RUNNING_YGGSCHEMA is set."""
+        YGGDRASIL_REGISTRATION_IN_PROGRESS is set."""
         pass
