@@ -19,8 +19,8 @@ class OutputDriver(ConnectionDriver):
                                    'and one or more comms/files.')
 
     def __init__(self, name, args, **kwargs):
-        kwargs.setdefault('ocomm_kws', {})
-        kwargs['ocomm_kws']['name'] = args
-        if kwargs['ocomm_kws'].get('comm', self._ocomm_type) == 'RMQComm':
-            kwargs['ocomm_kws']['queue'] = args
+        kwargs.setdefault('outputs', [{}])
+        kwargs['outputs'][0]['name'] = args
+        if kwargs['outputs'][0].get('commtype', self._ocomm_type) in ['rmq', 'RMQComm']:
+            kwargs['outputs'][0]['queue'] = args
         super(OutputDriver, self).__init__(name, **kwargs)
