@@ -478,3 +478,31 @@ class RModelDriver(InterpretedModelDriver):  # pragma: R
             '}',
         ]
         return out
+
+    @classmethod
+    def install_dependency(cls, package, package_manager=None, **kwargs):
+        r"""Install a dependency.
+
+        Args:
+            package (str): Name of the package that should be installed. If
+                the package manager supports it, this can include version
+                requirements.
+            package_manager (str, optional): Package manager that should be
+                used to install the package.
+            **kwargs: Additional keyword arguments are passed to the parent
+                class.
+
+        """
+        if package_manager in [None, 'cran', 'CRAN']:
+            if isinstance(package, list):
+                package = (
+                    'c(' + ', '.join([f"\"{x}\"" for x in package]) + ')')
+            else:
+                package = f'\"{package}\"'
+            kwargs.setdefault(
+                'command',
+                [cls.get_interpreter(), '-e',
+                 (f'\'install.packages({package}, dep=TRUE, '
+                  f'repos=\"http://cloud.r-project.org\")\'')])
+        return super(RModelDriver, cls).install_dependency(
+            package, package_manager=package_manager, **kwargs)
