@@ -10,7 +10,14 @@ class TestPythonModelParam(parent.TestInterpretedModelParam):
 class TestPythonModelDriverNoInit(TestPythonModelParam,
                                   parent.TestInterpretedModelDriverNoInit):
     r"""Test runner for PythonModelDriver without init."""
-    pass
+
+    def test_install_model_dependencies(self, deps=None):
+        r"""Test install_model_dependencies."""
+        if deps is None:
+            deps = [{'package': 'numpy', 'arguments': '-v'},
+                    'requests', 'pyyaml']
+        super(TestPythonModelDriverNoInit, self).test_install_model_dependencies(
+            deps=deps)
         
 
 class TestPythonModelDriverNoStart(TestPythonModelParam,
