@@ -4,7 +4,6 @@ import os
 import time
 import copy
 import signal
-import traceback
 import atexit
 from pprint import pformat
 from itertools import chain
@@ -24,6 +23,11 @@ COLOR_TRACE = '\033[30;43;22m'
 COLOR_NORMAL = '\033[0m'
 
 
+class IntegrationError(BaseException):
+    r"""Error raised when there is an error in an integration."""
+    pass
+
+
 class YggFunction(YggClass):
     r"""This class wraps function-like behavior around a model.
 
@@ -238,12 +242,12 @@ class YggRunner(YggClass):
         namespace (str, optional): Name that should be used to uniquely
             identify any RMQ exchange. Defaults to the value in the config
             file.
-        host (str, optional): Name of the host that the models will be launched
-            from. Defaults to None.
+        host (str, optional): Name of the host that the models will be
+            launched from. Defaults to None.
         rank (int, optional): Rank of this set of models if run in parallel.
             Defaults to 0.
-        ygg_debug_level (str, optional): Level for Ygg debug messages. Defaults
-            to environment variable 'YGG_DEBUG'.
+        ygg_debug_level (str, optional): Level for Ygg debug messages.
+            Defaults to environment variable 'YGG_DEBUG'.
         rmq_debug_level (str, optional): Level for RabbitMQ debug messages.
             Defaults to environment variable 'RMQ_DEBUG'.
         ygg_debug_prefix (str, optional): Prefix for Ygg debug messages.
@@ -257,10 +261,16 @@ class YggRunner(YggClass):
         partial_commtype (dict, optional): Communicator kwargs that should be
             be used for the connections to the unpaired channels when
             complete_partial is True. Defaults to None and will be ignored.
+        yaml_param (dict, optional): Parameters that should be used in
+            mustache formatting of YAML files. Defaults to None and is
+            ignored.
+        validate (bool, optional): If True, the validation scripts for each
+            modle (if present), will be run after the integration finishes
+            running. Defaults to False.
 
     Attributes:
-        namespace (str): Name that should be used to uniquely identify any RMQ
-            exchange.
+        namespace (str): Name that should be used to uniquely identify any
+            RMQ exchange.
         host (str): Name of the host that the models will be launched from.
         rank (int): Rank of this set of models if run in parallel.
         modeldrivers (dict): Model drivers associated with this run.
@@ -276,7 +286,7 @@ class YggRunner(YggClass):
                  ygg_debug_prefix=None, connection_task_method='thread',
                  as_service=False, complete_partial=False,
                  partial_commtype=None, production_run=False,
-                 mpi_tag_start=None):
+                 mpi_tag_start=None, yaml_param=None, validate=False):
         self.mpi_comm = None
         name = 'runner'
         if MPI is not None:
@@ -306,6 +316,7 @@ class YggRunner(YggClass):
         self.error_flag = False
         self.complete_partial = complete_partial
         self.partial_commtype = partial_commtype
+        self.validate = validate
         self.debug("Running in %s with path %s namespace %s rank %d",
                    os.getcwd(), sys.path, namespace, rank)
         # Update environment based on config
@@ -317,7 +328,7 @@ class YggRunner(YggClass):
         else:
             self.drivers = yamlfile.parse_yaml(
                 modelYmls, complete_partial=complete_partial,
-                partial_commtype=partial_commtype)
+                partial_commtype=partial_commtype, yaml_param=yaml_param)
             self.connectiondrivers = self.drivers['connection']
             self.modeldrivers = self.drivers['model']
             for x in self.modeldrivers.values():
@@ -436,6 +447,11 @@ class YggRunner(YggClass):
                 tprev = t
             self.info(40 * '=')
             self.info('%20s\t%f', "Total", tprev - t0)
+        if self.error_flag:
+            raise IntegrationError("Error running the integration.")
+        if self.validate:
+            for v in self.modeldrivers.values():
+                v['instance'].run_validation()
         return times
 
     @property
@@ -1029,10 +1045,5 @@ def get_runner(models, **kwargs):
 
 def run(*args, **kwargs):
     yggRunner = get_runner(*args, **kwargs)
-    try:
-        yggRunner.run()
-        yggRunner.debug("runner returns, exiting")
-    except Exception as ex:  # pragma: debug
-        yggRunner.pprint("yggrun exception: %s" % type(ex))
-        print(traceback.format_exc())
-    print('')
+    yggRunner.run()
+    yggRunner.debug("runner returns, exiting")
