@@ -1,3 +1,4 @@
+import pytest
 import os
 import unittest
 import signal
@@ -12,7 +13,7 @@ def test_get_runner():
     r"""Use get_runner to start a run."""
     namespace = "test_get_runner_%s" % str(uuid.uuid4)
     cr = runner.get_runner([ex_yamls['hello']['python']],
-                           namespace=namespace)
+                           namespace=namespace, validate=True)
     cr.run()
     cr.sleep()
 
@@ -22,8 +23,9 @@ def test_get_run():
     namespace = "test_run_%s" % str(uuid.uuid4)
     runner.run([ex_yamls['hello']['python']],
                namespace=namespace)
-    runner.run([ex_yamls['model_error']['python']],
-               namespace=namespace)
+    with pytest.raises(runner.IntegrationError):
+        runner.run([ex_yamls['model_error']['python']],
+                   namespace=namespace)
 
 
 def test_run_process_connections():
